@@ -66,7 +66,7 @@ def plotAsciiReactionRatesBar (r, scale=5):
 
 def plotPhasePortraitGrid  (r, pdfExport=None, figsize=(11,8), endTime=200, numPoints=500):
     '''
-    Plots a grid pf phase portraits of the floating species concentrations.
+    Plots a grid of phase portraits of the floating species concentrations.
     
     Args:
         r : reference
@@ -83,11 +83,15 @@ def plotPhasePortraitGrid  (r, pdfExport=None, figsize=(11,8), endTime=200, numP
     Example:
       >>> teUtils.plotting.plotPhasePortraitGrid (r)
     '''
+    print ("Starting....")
     slist = sorted (r.getFloatingSpeciesIds())
     r.reset()
+    print ('Run simulation...')
     m = r.simulate (0, endTime, numPoints, slist)
     n = r.getNumFloatingSpecies()
+    print ('Creating subplots (will take a while for a large grid)...')
     fig, axarr = _plt.subplots(n, n, figsize=figsize)
+    print ("Adjust subplots...")
     fig.subplots_adjust (wspace=0.15, hspace=0.15)
 
     count = 0
